@@ -5,10 +5,10 @@ coneA <- function(y, amat, w = NULL, face = NULL, msg = TRUE){
   if (!is.numeric(y) | length(y) == 0) {
     stop("y must be a numeric vector of length >= 1 !")
   }
-  if (!is.numeric(amat) | !is.matrix(amat)) {
-  # if (!is.matrix(amat) & !is(amat, "sparseMatrix")){
-     stop("amat must be a numeric matrix !")
-  # stop("amat must be a matrix or a sparse matrix from the Matrix package!")
+  #if (!is.numeric(amat) | !is.matrix(amat)) {
+  if (!is.matrix(amat) & !is(amat, "sparseMatrix")){
+     #stop("amat must be a numeric matrix !")
+     stop("amat must be a matrix or a sparse matrix from the Matrix package!")
   }
   if (ncol(amat) != length(y)) {
     stop("the column number of amat must equal the length of y !")
